--[[
OK! Here's the meat of the whole lua thing. I assume you know how lua works but I'll still try to thoroughly explain things so expect an odd compromise in tone.

Here's the documentation of Xlua: https://taloncrossing.com/xlua/docs/index.html
Keep it handy because it's mega-useful!
]]--

-- We call the 'test' function on MMF's side, see event 13.
function test()
	-- Just lua's own print() function. The output is displayed in the debug window but can also be obtained with the "On Print"-condition, as seen in the .mfa.
	print("Hello world")
	
	--[[ 
	Here we define our own function. The documentation recommends using the 'MF_'-prefix but as far as I know it's not necessary. As long as you make a matching event looking
	for this function on MMF's side, things should work.
	
	Our MF_print() function gets a single parameter, a string.
	]]--
	MF_print("Also hello world")
	
	--[[
	NOTE! If you have event groups that are disabled when the game starts, any MF-function calls inside the group stop working, probably because the game doesn't load those
	events at startup and thus lua doesn't 'know' of them. Prevent this by having the group enabled at startup and then disabling it.
	]]--
end

-- And here's 'moretest', event 15. It gets called with a single parameter, which is an object's fixed value (it could be anything, mind you!)
function moretest(id)
	--[[
	Here's an important trick that the mmfi library allows; by using the mmf.newObject() feature we can load the Active object into lua to directly access
	its values and features. This way we can greatly reduce the amount of stuff needed to be done on MMF's side. The Xlua documentation lists all objects
	that can be loaded this way into Xlua, and Looki has also made a separate library for their extension, Tilemap. Ask me if you want to hear more about that! :)
	
	Anyway! We pass the mmf.newObject() the fixed value of the object and thus create an entity lua understands, called 'object' in this case.
	]]--
	local object = mmf.newObject(id)
	
	-- We can read and write the objects alterable values, strings and flags (along with other stuff) in a variety of ways:
	-- We can refer to the value by its index (1-based, because that's how lua rolls.)
	local A = object.values[1]
	-- Or we can refer to it by its MMF alphabetical letter, which can make sense if you work with qualifiers a lot. Not super useful, though.
	local B = object.values[mmf.ALT_B]
	-- Technically we can also refer to the value by its name, but unfortunately this doesn't work once the game is compiled into an executable. So please don't use this.
	local C = object.values['Value C']
	
	-- A handy way to imitate that third option is to create a global variable that refers to the index of the desired value, and then referring to that variable.
	-- So here we refer to Value A (at value index 1) with the word 'POWER'. Note that we already defined the variable 'A' above.
	POWER = 1
	A = object.values[POWER]
	
	-- And here we print the three alterable values we obtained from the object. Nothing special here.
	print(tostring(A) .. ", " .. tostring(B) .. ", " .. tostring(C))
	
	-- Reading and writing strings works the same way. Here I read what's written in the object's alterable string A (index 1).
	local text = object.strings[1]
	
	-- Same with flags. Unfortunately in MMF2 these couldn't be named at all on MMF's side, so lua actually made it easier for me to keep track of them.
	if (object.flags[1] == false) then
		-- To demonstrate how to write into these variables, I change the flag 1 here to true or false based on its earlier state.
		object.flags[1] = true
	else
		object.flags[1] = false
	end
	
	local flag = object.flags[1]
	
	-- And here we print the string we obtained as well as the flag.
	print(text .. ", " .. tostring(flag))

	-- Functions in lua can also return values, showcased here by returning a random value between 1 and 5.
	return math.random(1,5)
end

function evenmoretest(int,flot,str)
	-- This is just to showcase a function with multiple parameters.
	print(tostring(int) .. ", " .. tostring(flot) .. ", " .. str)
	
	-- Here I call a function on MMF's side, MF_getcounter. This returns the value of the counter Counter_random.
	-- You can see how to return variables on MMF's side by looking at event 18.
	local countervalue = MF_getcounter()
	
	MF_print("The counter's value is " .. tostring(countervalue) .. "!")
end